@@ -1,6 +1,6 @@
 #' @title Show an interactive visual network representation
 #'   of your drake project.
-#' \lifecycle{maturing}
+#' \lifecycle{stable}
 #' @description To save time for repeated plotting,
 #' this function is divided into
 #' [drake_graph_info()] and [render_drake_graph()].
@@ -136,7 +136,7 @@ body(vis_drake_graph) <- config_util_body(vis_drake_graph_impl)
 
 #' @title Render a visualization using the data frames
 #'   generated by [drake_graph_info()].
-#' \lifecycle{maturing}
+#' \lifecycle{stable}
 #' @description This function is called inside
 #' [vis_drake_graph()], which typical users
 #' call more often.
@@ -188,8 +188,7 @@ body(vis_drake_graph) <- config_util_body(vis_drake_graph_impl)
 #'
 #' @param collapse Logical, whether to allow nodes to collapse
 #'   if you double click on them.
-#'   Analogous to `visNetwork::visOptions(collapse = TRUE)` or
-#'   `visNetwork::visOptions(collapse = TRUE)`.
+#'   Analogous to `visNetwork::visOptions(collapse = TRUE)`.
 #' @param on_select defines node selection event handling.
 #'   Either a string of valid JavaScript that may be passed to
 #'   `visNetwork::visEvents()`, or one of the following:
@@ -244,7 +243,7 @@ render_drake_graph <- function(
     navigationButtons = navigationButtons,
     ...
   )
-  out <- adjust_visnetwork_layout(graph = out, graph_info = graph_info)
+  out <- visNetwork::visHierarchicalLayout(graph = out, direction = "LR")
   out <- vis_add_on_select(graph = out, on_select = on_select)
   vis_render_webshot(graph = out, file = file, selfcontained = selfcontained)
 }
@@ -264,6 +263,10 @@ initialize_vis_network <- function(
     ...
   )
   out <- visNetwork::visNodes(out, physics = FALSE)
+  out <- visNetwork::visEdges(
+    out,
+    smooth = list(type = "cubicBezier", forceDirection = "horizontal")
+  )
   if (collapse) {
     out <- visNetwork::visOptions(out, collapse = TRUE)
   }
@@ -281,26 +284,6 @@ initialize_vis_network <- function(
   out
 }
 
-adjust_visnetwork_layout <- function(graph, graph_info) {
-  sugiyama <- nrow(graph_info$edges) &&
-    nrow(graph_info$nodes) > 10 &&
-    abs(diff(range(graph_info$nodes$x))) > 0.1 &&
-    abs(diff(range(graph_info$nodes$x))) > 0.1
-  if (sugiyama) {
-    graph <- visNetwork::visIgraphLayout(
-      graph = graph,
-      physics = FALSE,
-      randomSeed = 2017,
-      layout = "layout_with_sugiyama"
-    )
-  } else {
-    graph <- visNetwork::visHierarchicalLayout(graph, direction = "LR")
-  }
-  graph$x$nodes$x <- graph_info$nodes$x
-  graph$x$nodes$y <- graph_info$nodes$y
-  graph
-}
-
 vis_add_on_select <- function(graph, on_select) {
   out <- graph
   # Add on_select action
